==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/screens/login.dart <==
import 'package:flutter_firebase_basic_tools/logic/user_info_form_functions.dart';
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/widgets/user_info_form_container.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_firebase_basic_tools/flutter_firebase_basic_tools.dart';
import 'package:shared_preferences/shared_preferences.dart';

class Login extends StatefulWidget {
  const Login({
    @required this.topbarBackgroundColor,
    @required this.userInfoFormContainerColor1,
    @required this.userInfoFormContainerColor2,
    @required this.userInfoFormContainerColor3,
    @required this.rememberMeColor,
    @required this.loginButtonColor,
    @required this.forgotButtonColor,
    @required this.registerButtonColor,
    @required this.itemsTextColor,
    @required this.backgroundImagePath,
    @required this.apiKey,
  });

  final Color topbarBackgroundColor;
  final Color userInfoFormContainerColor1;
  final Color userInfoFormContainerColor2;
  final Color userInfoFormContainerColor3;
  final Color rememberMeColor;
  final Color loginButtonColor;
  final Color forgotButtonColor;
  final Color registerButtonColor;
  final Color itemsTextColor;
  final String backgroundImagePath;
  final String apiKey;

  @override
  _LoginState createState() => _LoginState();
}

class _LoginState extends State<Login> {
  bool rememberMe = false;

  TextEditingController emailInputController = TextEditingController();
  TextEditingController passwordInputController = TextEditingController();

  final GlobalKey<FormState> loginFormKey = GlobalKey<FormState>();

  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();

  String currentLanguage = "en";

  TranslationStream translationStream = TranslationStream();

  String heightString = "height";

  List<String> textList = [
    "Email",
    "Password",
    "Remember me",
    "Login",
    "Forgot password?",
    "Sign up",
  ];

  SharedPreferences prefs;

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("email") != null) {
      emailInputController.text = prefs.getString("email");
      rememberMe = true;
      setState(() {});
    }
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
    translationStream.init(textList, this);
    translationStream.translate(widget.apiKey);

    //widget

    Map<String, String> urlParams = Uri.base.queryParameters;

    print("urlParams: " + urlParams.toString());
    print("Uri.base: " + Uri.base.toString());
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: false,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: widget.topbarBackgroundColor,
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: LanguagePicker(
                currentLanguage: currentLanguage,
                parentWidget: this,
                itemsTextColor: widget.itemsTextColor,
                apiKey: "[API_KEY]",
              ),
            ),
          ],
          customLeading: null,
        ),
      ),
      body: UserInfoFormContainer(
        userInfoFormType: UserInfoFormType.login,
        cardColor: Colors.white,
        backgroundImagePath: widget.backgroundImagePath,
        linearGradient: LinearGradient(
          begin: FractionalOffset.bottomRight,
          end: FractionalOffset.topLeft,
          colors: [
            widget.userInfoFormContainerColor1,
            widget.userInfoFormContainerColor2,
            widget.userInfoFormContainerColor3,
          ],
          stops: [
            0.0,
            0.4,
            1.0,
          ],
        ),
        child: Form(
          key: loginFormKey,
          child: Column(
            children: <Widget>[
              Expanded(
                flex: 1,
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: textList[0],
                  ),
                  controller: emailInputController,
                  validator: (String value) => FormFieldValidators(
                    value: value,
                    type: FormFieldValidatorsType.email,
                  ).validate(),
                ),
              ),
              Expanded(
                flex: 1,
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: textList[1],
                  ),
                  controller: passwordInputController,
                  validator: (String value) => FormFieldValidators(
                    value: value,
                    type: FormFieldValidatorsType.password,
                  ).validate(),
                  obscureText: true,
                ),
              ),
              FlatButton(
                padding: EdgeInsets.all(0),
                onPressed: () {
                  rememberMe = !rememberMe;
                  setState(() {});
                },
                child: Row(
                  children: <Widget>[
                    Container(
                      child: Icon(
                        rememberMe
                            ? Icons.check_box
                            : Icons.check_box_outline_blank,
                        color: widget.rememberMeColor,
                      ),
                      margin: EdgeInsets.only(
                        right: 10,
                      ),
                    ),
                    Text(textList[2]),
                  ],
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width,
                child: RaisedButton(
                  color: widget.loginButtonColor,
                  onPressed: () {
                    List<TextEditingController> inputControllers = [
                      emailInputController,
                      passwordInputController,
                    ];

                    UserInfoFormFunctions().login(
                      context: context,
                      scaffoldKey: scaffoldKey,
                      rememberMe: rememberMe,
                      loginFormKey: loginFormKey,
                      inputControllers: inputControllers,
                      prefs: prefs,
                    );
                  },
                  child: Text(
                    textList[3],
                    textAlign: TextAlign.center,
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 12,
                      //fontWeight: FontWeight.bold,
                    ),
                  ),
                ),
              ),
              Expanded(
                flex: 1,
                child: Flex(
                  direction: isLandscape ? Axis.horizontal : Axis.vertical,
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: <Widget>[
                    FlatButton(
                      onPressed: () {
                        Navigator.pushNamed(context, '/ /forgot_password');
                      },
                      child: Text(
                        textList[4],
                        textAlign: TextAlign.center,
                        style: TextStyle(
                          color: widget.forgotButtonColor,
                          fontSize: 12,
                          //fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                    FlatButton(
                      onPressed: () {
                        Navigator.pushNamed(context, '/ /register');
                      },
                      child: Text(
                        textList[5],
                        textAlign: TextAlign.center,
                        style: TextStyle(
                          color: widget.registerButtonColor,
                          fontSize: 12,
                          //fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.27.tar.gz: lib/screens/login.dart <==
import 'package:flutter_firebase_basic_tools/logic/user_info_form_functions.dart';
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/widgets/user_info_form_container.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_firebase_basic_tools/flutter_firebase_basic_tools.dart';
import 'package:shared_preferences/shared_preferences.dart';

class Login extends StatefulWidget {
  const Login({
    @required this.topbarBackgroundColor,
    @required this.userInfoFormContainerColor1,
    @required this.userInfoFormContainerColor2,
    @required this.userInfoFormContainerColor3,
    @required this.rememberMeColor,
    @required this.loginButtonColor,
    @required this.forgotButtonColor,
    @required this.registerButtonColor,
    @required this.itemsTextColor,
    @required this.backgroundImagePath,
    @required this.apiKey,
  });

  final Color topbarBackgroundColor;
  final Color userInfoFormContainerColor1;
  final Color userInfoFormContainerColor2;
  final Color userInfoFormContainerColor3;
  final Color rememberMeColor;
  final Color loginButtonColor;
  final Color forgotButtonColor;
  final Color registerButtonColor;
  final Color itemsTextColor;
  final String backgroundImagePath;
  final String apiKey;

  @override
  _LoginState createState() => _LoginState();
}

class _LoginState extends State<Login> {
  bool rememberMe = false;

  TextEditingController emailInputController = TextEditingController();
  TextEditingController passwordInputController = TextEditingController();

  final GlobalKey<FormState> loginFormKey = GlobalKey<FormState>();

  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();

  String currentLanguage = "en";

  TranslationStream translationStream = TranslationStream();

  String heightString = "height";

  List<String> textList = [
    "Email",
    "Password",
    "Remember me",
    "Login",
    "Forgot password?",
    "Sign up",
  ];

  SharedPreferences prefs;

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("email") != null) {
      emailInputController.text = prefs.getString("email");
      rememberMe = true;
      setState(() {});
    }
  }

  updateTextList(int index, String newText){
    textList[index] = newText;
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate(widget.apiKey);
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
    translationStream.init(textList, updateTextList);
    translationStream.translate(widget.apiKey);

    //widget

    Map<String, String> urlParams = Uri.base.queryParameters;

    print("urlParams: " + urlParams.toString());
    print("Uri.base: " + Uri.base.toString());
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: false,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: widget.topbarBackgroundColor,
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: LanguagePicker(
                currentLanguage: currentLanguage,
                parentWidget: this,
                function: languagePickerCallback,
                itemsTextColor: widget.itemsTextColor,
                apiKey: "[API_KEY]",
              ),
            ),
          ],
          customLeading: null,
        ),
      ),
      body: UserInfoFormContainer(
        userInfoFormType: UserInfoFormType.login,
        cardColor: Colors.white,
        backgroundImagePath: widget.backgroundImagePath,
        linearGradient: LinearGradient(
          begin: FractionalOffset.bottomRight,
          end: FractionalOffset.topLeft,
          colors: [
            widget.userInfoFormContainerColor1,
            widget.userInfoFormContainerColor2,
            widget.userInfoFormContainerColor3,
          ],
          stops: [
            0.0,
            0.4,
            1.0,
          ],
        ),
        child: Form(
          key: loginFormKey,
          child: Column(
            children: <Widget>[
              Expanded(
                flex: 1,
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: textList[0],
                  ),
                  controller: emailInputController,
                  validator: (String value) => FormFieldValidators(
                    value: value,
                    type: FormFieldValidatorsType.email,
                  ).validate(),
                ),
              ),
              Expanded(
                flex: 1,
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: textList[1],
                  ),
                  controller: passwordInputController,
                  validator: (String value) => FormFieldValidators(
                    value: value,
                    type: FormFieldValidatorsType.password,
                  ).validate(),
                  obscureText: true,
                ),
              ),
              FlatButton(
                padding: EdgeInsets.all(0),
                onPressed: () {
                  rememberMe = !rememberMe;
                  setState(() {});
                },
                child: Row(
                  children: <Widget>[
                    Container(
                      child: Icon(
                        rememberMe
                            ? Icons.check_box
                            : Icons.check_box_outline_blank,
                        color: widget.rememberMeColor,
                      ),
                      margin: EdgeInsets.only(
                        right: 10,
                      ),
                    ),
                    Text(textList[2]),
                  ],
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width,
                child: RaisedButton(
                  color: widget.loginButtonColor,
                  onPressed: () {
                    List<TextEditingController> inputControllers = [
                      emailInputController,
                      passwordInputController,
                    ];

                    UserInfoFormFunctions().login(
                      context: context,
                      scaffoldKey: scaffoldKey,
                      rememberMe: rememberMe,
                      loginFormKey: loginFormKey,
                      inputControllers: inputControllers,
                      prefs: prefs,
                    );
                  },
                  child: Text(
                    textList[3],
                    textAlign: TextAlign.center,
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 12,
                      //fontWeight: FontWeight.bold,
                    ),
                  ),
                ),
              ),
              Expanded(
                flex: 1,
                child: Flex(
                  direction: isLandscape ? Axis.horizontal : Axis.vertical,
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: <Widget>[
                    FlatButton(
                      onPressed: () {
                        Navigator.pushNamed(context, '/ /forgot_password');
                      },
                      child: Text(
                        textList[4],
                        textAlign: TextAlign.center,
                        style: TextStyle(
                          color: widget.forgotButtonColor,
                          fontSize: 12,
                          //fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                    FlatButton(
                      onPressed: () {
                        Navigator.pushNamed(context, '/ /register');
                      },
                      child: Text(
                        textList[5],
                        textAlign: TextAlign.center,
                        style: TextStyle(
                          color: widget.registerButtonColor,
                          fontSize: 12,
                          //fontWeight: FontWeight.bold,
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
